# 2022-04-04 - ERC4626 Linear Pool V2

> ⚠️ **DEPRECATED: do not use** ⚠️
>
> This deployment has been deprecated in favor of a new version with critical fixes: [erc4626-linear-pool-v3](../20230206-erc4626-linear-pool-v3/).
> See https://forum.balancer.fi/t/reentrancy-vulnerability-scope-expanded/4345 for more details about the fixed vulnerability.

Second deployment of the `ERC4626LinearPoolFactory`, for Linear Pools with a ERC4626 yield-bearing token. This version supersedes the previous, which was released prior to finalization of EIP-4626.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Polygon mainnet addresses](./output/polygon.json)
- [Arbitrum mainnet addresses](./output/arbitrum.json)
- [Optimism mainnet addresses](./output/optimism.json)
- [Gnosis mainnet addresses](./output/gnosis.json)
- [Goerli testnet addresses](./output/goerli.json)
- [`ERC4626LinearPoolFactory` artifact](./artifact/ERC4626LinearPoolFactory.json)
